package com.yanzhu.manage.mapper;

import java.util.List;
import com.yanzhu.manage.domain.BusExamQuestionResult;

/**
 * 题库问题Mapper接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface BusExamQuestionResultMapper 
{
    /**
     * 查询题库问题
     * 
     * @param id 题库问题主键
     * @return 题库问题
     */
    public BusExamQuestionResult selectBusExamQuestionResultById(Long id);

    /**
     * 查询题库问题列表
     * 
     * @param busExamQuestionResult 题库问题
     * @return 题库问题集合
     */
    public List<BusExamQuestionResult> selectBusExamQuestionResultList(BusExamQuestionResult busExamQuestionResult);

    /**
     * 新增题库问题
     * 
     * @param busExamQuestionResult 题库问题
     * @return 结果
     */
    public int insertBusExamQuestionResult(BusExamQuestionResult busExamQuestionResult);

    /**
     * 修改题库问题
     * 
     * @param busExamQuestionResult 题库问题
     * @return 结果
     */
    public int updateBusExamQuestionResult(BusExamQuestionResult busExamQuestionResult);

    /**
     * 删除题库问题
     * 
     * @param id 题库问题主键
     * @return 结果
     */
    public int deleteBusExamQuestionResultById(Long id);

    /**
     * 批量删除题库问题
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusExamQuestionResultByIds(Long[] ids);
}
